@@ -1,10 +1,14 @@
 from .artifact import Artifact
 from .cluster import Cluster
-from .dataset import Dataset, VolumeOptions
+from .dataset import Dataset, DatasetRef
+from .dataset_tag import DatasetTag, DatasetVersionSummary
+from .dataset_version import DatasetVersion, DatasetVersionPreSignedS3Call, DatasetVersionPreSignedURL, \
+    DatasetVersionTagSummary
 from .deployment import Deployment, AutoscalingDefinition, AutoscalingMetric
 from .experiment import BaseExperiment, MultiNodeExperiment, SingleNodeExperiment, MpiMultiNodeExperiment
+from .experiment_dataset import ExperimentDataset, VolumeOptions
 from .hyperparameter import Hyperparameter
-from .job import Job
+from .job import Job, JobDataset
 from .log import LogRow
 from .machine import Machine, MachineEvent, MachineUtilization
 from .model import Model, ModelFile
@@ -12,6 +16,7 @@ from .notebook import Notebook, NotebookStart
 from .pagination import Pagination
 from .project import Project
 from .secret import Secret
+from .storage_provider import StorageProvider
 from .tag import Tag
 from .tensorboard import Instance, Tensorboard
 from .vm_type import VmType, VmTypeGpuModel
