@@ -1,4 +1,7 @@
 from .artifact import ArtifactSchema
+from .dataset import DatasetSchema, DatasetRefSchema
+from .dataset_tag import DatasetTagSchema
+from .dataset_version import DatasetVersionSchema, DatasetVersionPreSignedURLSchema
 from .deployment import DeploymentSchema, DeploymentCreateSchema
 from .experiment import BaseExperimentSchema, MultiNodeExperimentSchema, SingleNodeExperimentSchema, \
     MpiMultiNodeExperimentSchema
@@ -10,6 +13,7 @@ from .model import Model, ModelFileSchema
 from .notebook import NotebookSchema, NotebookStartSchema
 from .project import Project
 from .secret import SecretSchema
+from .storage_provider import StorageProviderSchema
 from .tag import TagSchema
 from .tensorboard import InstanceSchema, TensorboardSchema, TensorboardDetailSchema
 from .vm_type import VmTypeSchema, VmTypeGpuModelSchema
